package edu.nyu.scps.cursoradapter;

import android.app.LoaderManager;
import android.content.CursorLoader;
import android.content.Loader;
import android.database.Cursor;
import android.os.Bundle;
import android.provider.ContactsContract;
import android.support.v7.app.AppCompatActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;
import android.widget.Toast;


public class MainActivity extends AppCompatActivity
        implements LoaderManager.LoaderCallbacks<Cursor> {

    private static final int LOADER_ID = 0;
    private SimpleCursorAdapter adapter;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        LoaderManager loaderManager = getLoaderManager();
        loaderManager.initLoader(LOADER_ID, null, this); //will call onCreateLoader

        adapter = new SimpleCursorAdapter(
                this,
                android.R.layout.simple_list_item_1,
                null, //The cursor will be placed here by onLoadFinished.
                new String[] {ContactsContract.Contacts.DISPLAY_NAME},
                new int[]    {android.R.id.text1},
                0     //Flags are not needed when using a CursorLoader.
        );

        ListView listView = (ListView)findViewById(R.id.listView);
        listView.setAdapter(adapter);

        listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
                //Get the selectedString from the Cursor in the CursorAdapter.
                Cursor cursor = (Cursor)parent.getItemAtPosition(position);
                int displayNameIndex = cursor.getColumnIndex(ContactsContract.Data.DISPLAY_NAME);
                String selectedString = cursor.getString(displayNameIndex);

                //Another way to get the selectedString:
                //TextView textView = (TextView)view;
                //CharSequence charSequence = textView.getText();
                //String selectedString = charSequence.toString();

                String s = "Selected " + selectedString
                        + ", position = " + position
                        + ", id = " + id + ".";

                Toast toast = Toast.makeText(MainActivity.this, s, Toast.LENGTH_LONG);
                toast.show();
            }
        });
    }

    @Override
    public Loader<Cursor> onCreateLoader(int id, Bundle args) {
        if (id == LOADER_ID) {
            //This CursorLoader will be passed to onLoadFinished.
            return new CursorLoader(
                    this,
                    ContactsContract.Contacts.CONTENT_URI,
                    new String[] {
                        ContactsContract.Contacts._ID,
                        ContactsContract.Contacts.DISPLAY_NAME
                    },
                    null, //Which rows?  null means every row.
                    null, //Which rows?
                    ContactsContract.Contacts.DISPLAY_NAME + " COLLATE LOCALIZED ASC" //ascending
            );
        }
        return null;
    }

    @Override
    public void onLoadFinished(Loader<Cursor> loader, Cursor cursor) {
        adapter.swapCursor(cursor);
    }

    @Override
    public void onLoaderReset(Loader<Cursor> loader) {
        adapter.swapCursor(null);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
}
